@@ -1,4 +1,4 @@
 # Copyright (C) 2003-2023 Namcap contributors, see AUTHORS for details.
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from . import util, rules  # noqa: F401
+from . import rules, util  # noqa: F401
