@@ -1,13 +1,15 @@
 # Copyright (C) 2003-2023 Namcap contributors, see AUTHORS for details.
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from license_expression import BaseSymbol, LicenseSymbol, LicenseWithExceptionSymbol, get_spdx_licensing
-from Namcap.ruleclass import TarballRule
-from Namcap.package import load_from_db
-from Namcap.util import is_debug
 from pathlib import Path
 from tarfile import TarFile, TarInfo
 
+from license_expression import BaseSymbol, LicenseSymbol, LicenseWithExceptionSymbol, get_spdx_licensing
+
+from Namcap.package import PacmanPackage, load_from_db
+from Namcap.ruleclass import TarballRule
+from Namcap.util import is_debug
+
 
 def get_license_canonicalized(license: str) -> str:
     """Get the canonicalized form of a license string
@@ -18,7 +20,27 @@ def get_license_canonicalized(license: str) -> str:
     return str(licensing.parse(license, strict=True))
 
 
-def get_license_symbols(license: str) -> set[BaseSymbol]:
+def strip_plus_from_license(license: BaseSymbol) -> BaseSymbol:
+    """Remove a "+" suffix from the license symbol if it contains one
+
+    The license_expression module does not support the SPDX "+" operator, but parses it as part of the license
+    symbol instead. This function strips the operator from the symbol if it is found.
+
+    License identifiers ending with "-only" or "-or-later" should not be used with the plus operator. If such
+    license identifier is detected, the plus operator is left intact and this will be later reported as an
+    unknown license symbol.
+    """
+    license_str = str(license)
+    if license_str[-1] != "+" or license_str.startswith("LicenseRef-"):
+        return license
+    license_id = license_str[:-1]
+    if license_id.endswith(("-only", "-or-later")):
+        return license
+    else:
+        return LicenseSymbol(license_id)
+
+
+def get_license_symbols(pkg_license: str) -> set[BaseSymbol]:
     """Extract all license symbols from a license string
 
     This function may raise an Exception if it's not possible to derive any meaning from the input string.
@@ -26,8 +48,17 @@ def get_license_symbols(license: str) -> set[BaseSymbol]:
     SPDX license exception identifier.
     """
     licensing = get_spdx_licensing()
-    symbols = licensing.parse(license, strict=True)
-    return symbols.symbols
+    if (license_expression := licensing.parse(pkg_license, strict=True)) is None:
+        raise ValueError("Empty license string")
+    license_symbols: set[BaseSymbol] = set()
+    for symbol in license_expression.symbols:
+        if isinstance(symbol, LicenseWithExceptionSymbol):
+            license, exception = list(symbol.decompose())
+            license = strip_plus_from_license(license)
+            license_symbols.add(LicenseWithExceptionSymbol(license, exception))
+        else:
+            license_symbols.add(strip_plus_from_license(symbol))
+    return license_symbols
 
 
 def get_common_spdx_license_identifiers() -> set[BaseSymbol]:
@@ -151,10 +182,10 @@ def get_symlink_target(member: TarInfo) -> str:
     return symlink_target
 
 
-def package_license_files(tar: TarFile | None, pkgname: str) -> tuple[dict[str, str], str | None]:
+def package_license_files(tar: TarFile | None, pkgname: str) -> tuple[dict[str, bool], str | None]:
     """Return the license files referenced in a package and whether the license dir is a symlink"""
     license_dir_symlink = None
-    files: dict[str, str] = {}
+    files: dict[str, bool] = {}
 
     if not tar:
         return (files, license_dir_symlink)
@@ -202,7 +233,7 @@ class package(TarballRule):
     name = "licensepkg"
     description = "Verifies license is included in a package file"
 
-    def analyze(self, pkginfo, tar: TarFile | None):
+    def analyze(self, pkginfo: PacmanPackage, tar: TarFile | None) -> None:
         # return early, as we do not check debug packages
         if is_debug(pkginfo):
             return
@@ -237,7 +268,8 @@ class package(TarballRule):
         known_licenses = get_known_spdx_license_identifiers()
         known_exceptions = get_known_spdx_license_exceptions()
 
-        # check if any license (ignoring exception) symbols are unknown (and add errors for them, if they are not prefixed with LicenseRef-)
+        # check if any license (ignoring exception) symbols are unknown
+        # (and add errors for them, if they are not prefixed with LicenseRef-)
         for license in get_unknown_license_symbols(license_symbols, known_licenses, known_exceptions):
             if not str(license).startswith("LicenseRef-"):
                 self.errors.append(("unknown-spdx-license-identifier %s", (str(license),)))
@@ -283,7 +315,8 @@ class package(TarballRule):
                             break
 
             outbound_licenses = [license for (license, exists) in pkg_licenses.items() if not exists]
-            # there are symlinks to license files in other pkgs, but those files are missing (or the package in question is not a dependency)
+            # there are symlinks to license files in other pkgs, but those files are missing
+            # (or the package in question is not a dependency)
             for outbound_license in outbound_licenses:
                 self.errors.append(
                     (
@@ -298,7 +331,7 @@ class package(TarballRule):
 
             # try to figure out which other package contains the actual files
             other_pkg = (
-                list(Path(license_dir_symlink.lstrip("usr/share/licenses/")).parts)[0]
+                list(Path(license_dir_symlink.removeprefix("usr/share/licenses/")).parts)[0]
                 if license_dir_symlink.startswith("usr/share/licenses/")
                 else None
             )
