@@ -2,8 +2,9 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 import os
-from Namcap.tests.makepkg import MakepkgTest
+
 import Namcap.rules.fileownership
+from Namcap.tests.makepkg import MakepkgTest
 
 
 class FileOwnershipTest(MakepkgTest):
@@ -12,10 +13,10 @@ pkgname=__namcap_test_fileownership
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64' 'aarch64' 'riscv64' 'loongarch64')
+arch=('i686' 'x86_64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
-depends=('musl')
+depends=('glibc')
 source=()
 build() {
   true
@@ -23,7 +24,7 @@ build() {
 package() {
   mkdir -p ${pkgdir}/usr/bin
   touch ${pkgdir}/usr/bin/program
-  chown root:114514 ${pkgdir}/usr/bin/program
+  chown root:storage ${pkgdir}/usr/bin/program
 }
 """
 
@@ -33,6 +34,6 @@ package() {
             f.write(self.pkgbuild)
         self.run_makepkg()
         pkg, r = self.run_rule_on_tarball(os.path.join(self.tmpdir, pkgfile), Namcap.rules.fileownership.package)
-        self.assertEqual(r.errors, [("incorrect-owner %s (%s:%s)", ("usr/bin/program", "root", "114514"))])
+        self.assertEqual(r.errors, [("incorrect-owner %s (%s:%s)", ("usr/bin/program", "root", "storage"))])
         self.assertEqual(r.warnings, [])
         self.assertEqual(r.infos, [])
