@@ -2,8 +2,9 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 import os
-from Namcap.tests.makepkg import MakepkgTest
+
 import Namcap.rules.lotsofdocs
+from Namcap.tests.makepkg import MakepkgTest
 
 
 class LotsOfDocsTest(MakepkgTest):
@@ -12,7 +13,7 @@ pkgname=__namcap_test_lotsofdocs
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64' 'riscv64')
+arch=('i686' 'x86_64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
 depends=('glibc')
@@ -37,5 +38,5 @@ package() {
         self.assertEqual(r.errors, [])
         tag, value = r.warnings[0]
         self.assertEqual(tag, "lots-of-docs %f")
-        self.assertGreater(value, 50)
+        self.assertGreater(value, (50,))
         self.assertEqual(r.infos, [])
