@@ -2,8 +2,9 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 import os
-from Namcap.tests.makepkg import MakepkgTest
+
 import Namcap.rules.rpath
+from Namcap.tests.makepkg import MakepkgTest
 
 
 class RpathTest(MakepkgTest):
@@ -12,16 +13,16 @@ pkgname=__namcap_test_rpath
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64' 'aarch64' 'riscv64' 'loongarch64')
+arch=('i686' 'x86_64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
-depends=('musl')
+depends=('glibc')
 source=()
 options=(!purge !zipman)
 build() {
   cd "${srcdir}"
   echo "int main() { return 0; }" > main.c
-  /usr/bin/cc -o main.o -c main.c
+  /usr/bin/gcc -o main.o -c main.c
   # core/binutils defaults to DT_RUNPATH since 2.39-4. Force old DT_RPATH here for testing.
   /usr/bin/ld -o main --disable-new-dtags --rpath /home/evil/lib main.o -lc
 }
