@@ -2,8 +2,9 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 import os
-from Namcap.tests.makepkg import MakepkgTest
+
 import Namcap.rules.scrollkeeper
+from Namcap.tests.makepkg import MakepkgTest
 
 
 class ScrollkeeperTest(MakepkgTest):
@@ -12,7 +13,7 @@ pkgname=__namcap_test_scrollkeeper
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64' 'riscv64')
+arch=('i686' 'x86_64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
 depends=('glibc')
