@@ -2,8 +2,9 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 import os
-from Namcap.tests.makepkg import MakepkgTest
+
 import Namcap.rules.symlink
+from Namcap.tests.makepkg import MakepkgTest
 
 
 class SymlinkTest(MakepkgTest):
@@ -12,10 +13,10 @@ pkgname=__namcap_test_symlink
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64' 'aarch64' 'riscv64' 'loongarch64')
+arch=('i686' 'x86_64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
-depends=('musl')
+depends=('glibc')
 source=()
 options=(!purge !zipman)
 backup=(etc/imaginary_file.conf)
