@@ -1,8 +1,8 @@
 # Copyright (C) 2003-2023 Namcap contributors, see AUTHORS for details.
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from Namcap.tests.pkgbuild_test import PkgbuildTest
 import Namcap.rules.splitpkgbuild as module
+from Namcap.tests.pkgbuild_test import PkgbuildTest
 
 
 class NamcapSplitPkgbuildTest(PkgbuildTest):
@@ -16,7 +16,7 @@ pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
 url="http://mypackage.sf.net/"
-arch=('i686' 'x86_64' 'riscv64')
+arch=('i686' 'x86_64')
 depends=('glibc')
 license=('GPL-3.0-or-later')
 options=('!libtool')
@@ -44,7 +44,7 @@ package_prog1() {
     def test_example1(self):
         "Example 1 : missing package_* function"
         r = self.run_on_pkg(self.pkgbuild1)
-        self.assertEqual(r.errors, [("missing-pkgfunction %s", "prog2")])
+        self.assertEqual(r.errors, [("missing-pkgfunction %s", ("prog2",))])
         self.assertEqual(r.warnings, [])
         self.assertEqual(r.infos, [])
 
@@ -60,7 +60,7 @@ pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
 url="http://mypackage.sf.net/"
-arch=('i686' 'x86_64' 'riscv64')
+arch=('i686' 'x86_64')
 makedepends=('gtk2')
 license=('GPL-3.0-or-later')
 options=('!libtool')
@@ -96,6 +96,6 @@ package_prog2() {
     def test_example1(self):
         "Example 1: missing makedepend"
         r = self.run_on_pkg(self.pkgbuild1)
-        self.assertEqual(r.errors, [("missing-makedeps %s", str(["lib1", "lib2"]))])
+        self.assertEqual(r.errors, [("missing-makedeps %s", (str(["lib1", "lib2"]),))])
         self.assertEqual(r.warnings, [])
         self.assertEqual(r.infos, [])
